@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2010 The Music Player Daemon Project
+   (c) 2003-2015 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -62,7 +62,7 @@ mpd_parse_welcome(struct mpd_connection *connection, const char *output)
 	}
 
 	tmp = &output[strlen(MPD_WELCOME_MESSAGE)];
-	connection->version[0] = strtol(tmp, &test, 10);
+	connection->version[0] = strtoul(tmp, &test, 10);
 	if (test == tmp) {
 		mpd_error_code(&connection->error, MPD_ERROR_MALFORMED);
 		mpd_error_message(&connection->error,
@@ -71,9 +71,9 @@ mpd_parse_welcome(struct mpd_connection *connection, const char *output)
 	}
 
 	if (*test == '.') {
-		connection->version[1] = strtol(test + 1, &test, 10);
+		connection->version[1] = strtoul(test + 1, &test, 10);
 		if (*test == '.')
-			connection->version[2] = strtol(test + 1, &test, 10);
+			connection->version[2] = strtoul(test + 1, &test, 10);
 		else
 			connection->version[2] = 0;
 	} else {
@@ -238,6 +238,15 @@ void mpd_connection_free(struct mpd_connection *connection)
 	free(connection);
 }
 
+void
+mpd_connection_set_keepalive(struct mpd_connection *connection,
+                             bool keepalive)
+{
+	assert(connection != NULL);
+
+	mpd_async_set_keepalive(connection->async, keepalive);
+}
+
 const struct mpd_settings *
 mpd_connection_get_settings(const struct mpd_connection *connection)
 {
